# 🐬 bluer-ugv

🐬 `@ugv` is a [bluer-ai](https://github.com/kamangir/bluer-ai) plugin for [ROS](https://www.ros.org/).

```bash
pip install bluer_ugv
```

|   |   |
| --- | --- |
| [`bluer_swallow`](./bluer_ugv/docs/bluer_swallow) [![image](https://github.com/kamangir/assets2/blob/main/bluer-swallow/20250701_2206342_1.gif?raw=true)](./bluer_ugv/docs/bluer_swallow) based on power wheels. | [`bluer-fire`](./bluer_ugv/docs/bluer_fire) [![image](https://github.com/kamangir/assets/blob/main/bluer-ugv/bluer-fire.png?raw=true)](./bluer_ugv/docs/bluer_fire) based on a used car. |
| [`bluer_sparrow`](./bluer_ugv/docs/bluer_sparrow) [![image](https://github.com/kamangir/assets2/blob/main/bluer-sparrow/20250713_172442_1.gif?raw=true)](./bluer_ugv/docs/bluer_sparrow) bluer_swallow's little sister. | [`bluer-beast`](./bluer_ugv/docs/bluer_beast) [![image](https://github.com/waveshareteam/ugv_rpi/raw/main/media/UGV-Rover-details-23.jpg)](./bluer_ugv/docs/bluer_beast) based on [UGV Beast PI ROS2](https://www.waveshare.com/wiki/UGV_Beast_PI_ROS2). |

# aliases

[@swallow](./bluer_ugv/docs/aliases/swallow.md).

---

> 🌀 [`blue-rover`](https://github.com/kamangir/blue-rover) for the [Global South](https://github.com/kamangir/bluer-south).

---


[![pylint](https://github.com/kamangir/bluer-ugv/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/bluer-ugv/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/bluer-ugv/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/bluer-ugv/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/bluer-ugv/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/bluer-ugv/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/bluer-ugv.svg)](https://pypi.org/project/bluer-ugv/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/bluer-ugv)](https://pypistats.org/packages/bluer-ugv)

built by 🌀 [`bluer README`](https://github.com/kamangir/bluer-objects/tree/main/bluer_objects/README), based on 🐬 [`bluer_ugv-6.417.1`](https://github.com/kamangir/bluer-ugv).

